Result

Struct Result 

#[non_exhaustive]
pub struct Result<'a, Registry, Resources, Iterator, ResourceViews, EntryViews, EntryIndices>
where Registry: Registry,
{ pub iter: Iterator, pub resources: ResourceViews, pub entries: Entries<'a, Registry, Resources, EntryViews, EntryIndices>, }
The result of a query.

This struct contains both the iterator over the viewed entities, as well as the viewed resources.

Example

The example below iterates over the entities returned by a query and counts them using a shared counter resource.

use brood::{World, Registry, resources, Query, entities, query::{Views, filter, result}};

// Components
#[derive(Clone)]
struct A(u32);
#[derive(Clone)]
struct B(char);

// Resource
#[derive(Debug, PartialEq)]
struct Count(u32);

let mut world = World::<Registry!(A, B), _>::with_resources(resources!(Count(0)));

world.extend(entities!((A(42), B('a')); 100));

let query_result = world.query(Query::<Views!(&A, &B), filter::None, Views!(&mut Count)>::new());
let result!(count) = query_result.resources;

for result!(_a, _b) in query_result.iter {
    count.0 += 1;
}

assert_eq!(world.get::<Count, _>(), &Count(100));

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
iter: Iterator

The viewed entities.

resources: ResourceViews

The viewed resources.

entries: Entries<'a, Registry, Resources, EntryViews, EntryIndices>

Entry access for the components specified by EntryViews.

This allows entity Entry lookup while iterating over the entities viewed by this query.