pub struct Not<Filter> { /* private fields */ }Expand description
Filter using the logical inverse of another Filter.
This filters out any entities which would not have been filtered by the Filter.
Example
use brood::query::filter;
// Define a component.
struct Foo(usize);
// Define a filter for the component above.
type HasFoo = filter::Has<Foo>;
// Define a component that is the inverse of the filter above.
type DoesNotHaveFoo = filter::Not<HasFoo>;Trait Implementations